@@ -1,5 +1,5 @@
-from gaiaxpy.file_parser import ExternalParser, InternalContinuousParser
-
+from gaiaxpy.file_parser.parse_internal_continuous import InternalContinuousParser
+from gaiaxpy.file_parser.parse_external import ExternalParser
 
 def external():
     return ExternalParser()
@@ -14,9 +14,10 @@ def raise_error():
 
 function_parser_dict = {'apply_colour_equation': raise_error,
                         'convert': internal_continuous,
-                        'generate': internal_continuous,
                         '_calibrate': internal_continuous,
-                        'calibrate': internal_continuous}
+                        'calibrate': internal_continuous,
+                        'generate': internal_continuous,
+                        'get_inverse_covariance_matrix': internal_continuous}
 
 
 class FileReader(object):
