@@ -1,14 +1,14 @@
 import json
+
 import numpy as np
 import pandas as pd
+
 from gaiaxpy.core.generic_functions import str_to_array
 
 
 def parse_matrices(string):
-    if len(string) == 0:
-        return None
-    else:
-        return np.array(json.loads(string))
+    return None if len(string) == 0 else np.array(json.loads(string))
+
 
 def get_spectrum_with_source_id(source_id, spectra):
     if isinstance(spectra, list):
@@ -30,13 +30,6 @@ def get_spectrum_with_source_id_and_xp(source_id, xp, spectra):
     raise ValueError('Spectrum does not exist or function is not defined for variable spectra type.')
 
 
-def df_columns_to_array(df, columns):
-    for index, row in df.iterrows():
-        for column in columns:
-            df[column][index] = str_to_array(row[column])
-    return df
-
-
 def pos_file_to_array(pos_file):
     df = pd.read_csv(pos_file, float_precision='round_trip', converters={'pos': (lambda x: str_to_array(x))})
     return df['pos'].iloc[0]
